document.addEventListener('DOMContentLoaded', () => {
    const questLinks = document.querySelectorAll('a[href="quest://current-page"]');

    if (questLinks.length === 0) return;

    // Function to get the current page URL via REST API or fallback
    const getCurrentPageUrl = async () => {
        try {
            // Find the REST API link in the page's <head>
            const link = document.querySelector('link[rel="alternate"][type="application/json"]');
            if (!link) {
                console.warn('REST API link not found, using window.location.href');
                return window.location.href;
            }

            const response = await fetch(link.href, {
                headers: {
                    'X-WP-Nonce': questLinkProcessor.nonce,
                },
            });

            if (!response.ok) {
                throw new Error('Failed to fetch page data');
            }

            const data = await response.json();
            return data.link || window.location.href;
        } catch (error) {
            console.warn('Error fetching current page URL:', error);
            return window.location.href;
        }
    };

    // Function to create the Quest Web Launch URL
    const createQuestUrl = (pageUrl) => {
        const sendToQuestUrl = new URL('https://www.oculus.com/open_url/');
        sendToQuestUrl.searchParams.set('url', pageUrl);
        return sendToQuestUrl.href;
    };

    // Process each Quest link
    questLinks.forEach(async (link) => {
        const pageUrl = await getCurrentPageUrl();
        link.href = createQuestUrl(pageUrl);
        link.target = '_blank';
        link.rel = 'noopener';
        link.classList.add('quest-link'); // Add class for styling
    });
});